@@ -1,10 +1,10 @@
-# last modified 2016-04-01
+# last modified 2019-12-24
 
 DeltaMethod <- function(model, g, level=0.95){
   coefs <- coef(model)
   p <- length(coefs)
   nms <- if (names(coefs)[1] == "(Intercept)") paste0("b", 0:(p - 1)) else paste0("b", 1:p)
-  res <- car::deltaMethod(model, g, parameterNames=nms)
+  res <- car::deltaMethod(model, g, level=level, parameterNames=nms)
   result <- list(test=res, coef=rbind(names(coefs), nms))
   class(result) <- "DeltaMethod"
   result
